﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnboundLib;
using UnboundLib.Cards;
using UnityEngine;

namespace TBNRcards.Cards
{
    class ShoulderCannon : CustomCard
    {
        public override void SetupCard(CardInfo cardInfo, Gun gun, ApplyCardStats cardStats, CharacterStatModifiers statModifiers, Block block)
        {
            gun.damage = 3.5f;
            gun.projectileSize = 2f;
            gun.attackSpeed = .5f;
            gun.reloadTimeAdd = 2;
            gun.destroyBulletAfter = 1000;

            cardInfo.allowMultiple = false;
            UnityEngine.Debug.Log($"[{TBNRcards.ModInitials}][Card] {GetTitle()} has been setup.");
        }
        public override void OnAddCard(Player player, Gun gun, GunAmmo gunAmmo, CharacterData data, HealthHandler health, Gravity gravity, Block block, CharacterStatModifiers characterStats)
        {
            player.gameObject.GetOrAddComponent<SingleBulletMono>();
            UnityEngine.Debug.Log($"[{TBNRcards.ModInitials}][Card] {GetTitle()} has been added to player {player.playerID}.");
        }
        public override void OnRemoveCard(Player player, Gun gun, GunAmmo gunAmmo, CharacterData data, HealthHandler health, Gravity gravity, Block block, CharacterStatModifiers characterStats)
        {
            UnityEngine.Debug.Log($"[{TBNRcards.ModInitials}][Card] {GetTitle()} has been removed from player {player.playerID}.");
        }

        internal static CardInfo Card = null;

        protected override string GetTitle()
        {
            return "Shoulder Cannon";
        }
        protected override string GetDescription()
        {
            return "A carryable cannon. That is all";
        }
        protected override GameObject GetCardArt()
        {
            return null;
        }
        protected override CardInfo.Rarity GetRarity()
        {
            return CardInfo.Rarity.Rare;
        }
        protected override CardInfoStat[] GetStats()
        {
            return new CardInfoStat[]
            {
                new CardInfoStat()
                {
                    positive = true,
                    stat = "Damage",
                    amount = "+250%",
                    simepleAmount = CardInfoStat.SimpleAmount.notAssigned
                },
                new CardInfoStat()
                {
                    positive = true,
                    stat = "Bullet size",
                    amount = "+100%",
                    simepleAmount = CardInfoStat.SimpleAmount.notAssigned
                },
                new CardInfoStat()
                {
                    positive = false,
                    stat = "Attack speed",
                    amount = "-50%",
                    simepleAmount = CardInfoStat.SimpleAmount.notAssigned
                },
                new CardInfoStat()
                {
                    positive = false,
                    stat = "Reload speed",
                    amount = "+100%",
                    simepleAmount = CardInfoStat.SimpleAmount.notAssigned
                },
                new CardInfoStat()
                {
                    positive = false,
                    stat = "Projectile and burst",
                    amount = "Permanently 1",
                    simepleAmount = CardInfoStat.SimpleAmount.notAssigned
                }
            };
        }
        protected override CardThemeColor.CardThemeColorType GetTheme()
        {
            return CardThemeColor.CardThemeColorType.EvilPurple;
        }
        public override string GetModName()
        {
            return "TBNRC";
        }

        public class SingleBulletMono : MonoBehaviour
        {
            private Player _player;
            private Gun _gun;
            public void Start()
            {
                if (_player == null) _player = gameObject.GetComponent<Player>();
            }
            private void Update()
            {
                if (_player == null) return;
                _gun = _player.GetComponent<Holding>().holdable.GetComponent<Gun>();
                
                var _projectiles = _gun.numberOfProjectiles * 0;
                var __projectiles = _projectiles + 1;
                var _bursts = _gun.bursts * 0;
                var __bursts = _bursts + 1;
                var _spread = _gun.spread * 0;

                //_gun.soundShotModifier.single sound;

                _gun.numberOfProjectiles = __projectiles;
                _gun.bursts = __bursts;
                _gun.spread = _spread;
            }
        }
    }
}
